Auto-removal of grids by `~.Axes.pcolor` and `~.Axes.pcolormesh`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
`~.Axes.pcolor` and `~.Axes.pcolormesh` currently remove any visible axes major
grid.  This behavior is deprecated; please explicitly call ``ax.grid(False)``
to remove the grid.
